@@ -123,6 +123,7 @@ class TaskGraphGenerator:
         parameters: Union[Parameters, Callable[[GraphConfig], Parameters]],
         decision_task_id: str = "DECISION-TASK",
         write_artifacts: bool = False,
+        enable_verifications: bool = True,
     ):
         """
         @param root_dir: root directory containing the Taskgraph config.yml file
@@ -136,6 +137,7 @@ class TaskGraphGenerator:
         self._parameters = parameters
         self._decision_task_id = decision_task_id
         self._write_artifacts = write_artifacts
+        self._enable_verifications = enable_verifications
 
         # start the generator
         self._run = self._run()  # type: ignore
@@ -258,7 +260,7 @@ class TaskGraphGenerator:
         graph_config.register()
 
         # Initial verifications that don't depend on any generation state.
-        verifications("initial")
+        self.verify("initial")
 
         if callable(self._parameters):
             parameters = self._parameters(graph_config)
@@ -289,7 +291,7 @@ class TaskGraphGenerator:
         kinds = {
             kind.name: kind for kind in self._load_kinds(graph_config, target_kinds)
         }
-        verifications("kinds", kinds)
+        self.verify("kinds", kinds)
 
         edges = set()
         for kind in kinds.values():
@@ -437,9 +439,11 @@ class TaskGraphGenerator:
             self._run_results[k] = v
         return self._run_results[name]
 
-    def verify(self, name, obj, *args, **kwargs):
-        verifications(name, obj, *args, **kwargs)
-        return name, obj
+    def verify(self, name, *args, **kwargs):
+        if self._enable_verifications:
+            verifications(name, *args, **kwargs)
+        if args:
+            return name, args[0]
 
 
 def load_tasks_for_kind(parameters, kind, root_dir=None):
