@@ -3,6 +3,8 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import os.path
+from pathlib import Path
+from unittest.mock import Mock, patch
 
 import pytest
 
@@ -30,3 +32,19 @@ def test_graph_config_basic():
 
     with pytest.raises(TypeError):
         graph_config["baz"] = 2
+
+
+def test_vcs_root_with_non_standard_dir():
+    """Test that  property uses vcs_root correctly with a non standard path"""
+
+    path_repo = "/path/to/repo"
+    mock_repo = Mock()
+    mock_repo.path = path_repo
+
+    with patch("taskgraph.config.get_repository", return_value=mock_repo):
+        graph_config = GraphConfig({"foo": "bar"}, "root/data")
+        vcs_root = graph_config.vcs_root
+
+        expected_path = Path("/path/to/repo")
+
+        assert vcs_root == expected_path
