@@ -13,6 +13,7 @@ from unittest.mock import Mock
 import pytest
 
 import taskgraph
+from taskgraph.util.caches import CACHES
 
 
 @pytest.fixture(scope="module")
@@ -435,3 +436,48 @@ def test_display_python_version_should_output_python_versions(run_task_mod, caps
 
     output = capsys.readouterr().out
     assert ("Python version: 3." in output) or ("Python version: 2." in output) is True
+
+
+@pytest.fixture
+def run_main(tmp_path, mocker, mock_stdin, run_task_mod):
+    base_args = [
+        f"--task-cwd={str(tmp_path)}",
+    ]
+
+    base_command_args = [
+        "bash",
+        "-c",
+        "echo hello",
+    ]
+
+    m = mocker.patch.object(run_task_mod.os, "getcwd")
+    m.return_value = "/builds/worker"
+
+    def inner(extra_args=None, env=None):
+        extra_args = extra_args or []
+        env = env or {}
+
+        mocker.patch.object(run_task_mod.os, "environ", env)
+
+        args = base_args + extra_args
+        args.append("--")
+        args.extend(base_command_args)
+
+        result = run_task_mod.main(args)
+        return result, env
+
+    return inner
+
+
+def test_main_abspath_environment(run_main):
+    envvars = ["MOZ_FETCHES_DIR", "UPLOAD_DIR"]
+    envvars += [cache["env"] for cache in CACHES.values() if "env" in cache]
+    env = {key: "file" for key in envvars}
+    env["FOO"] = "file"
+
+    result, env = run_main(env=env)
+    assert result == 0
+
+    assert env.get("FOO") == "file"
+    for key in envvars:
+        assert env[key] == "/builds/worker/file"
